<?php
/*
Plugin Name:  Canonical Ayarları
Plugin URI: https://www.seogle.com.tr/wordpress-eklentilerimiz/
Description: Sayfalarınızda ve içeriklerinizde Canonical'i belirlemenizi sağlar.
Version: 1.0
Author: Okan CERİT
Author URI: https://www.linkedin.com/in/okancerit/
License: GPL2
*/

// Yönetici panelinde özel alanı ekle
function add_custom_canonical_meta_box() {
    add_meta_box(
        'custom-canonical-meta-box',
        'Custom Canonical URL',
        'display_custom_canonical_meta_box',
        ['post', 'page'],
        'normal',
        'high'
    );
}
add_action('add_meta_boxes', 'add_custom_canonical_meta_box');

// Özel alan içeriği
function display_custom_canonical_meta_box($post) {
    $custom_canonical_url = get_post_meta($post->ID, '_custom_canonical_url', true);
    ?>
    <label for="custom_canonical_url">Custom Canonical URL:</label>
    <input type="text" id="custom_canonical_url" name="custom_canonical_url" value="<?php echo esc_attr($custom_canonical_url); ?>" style="width:100%;" />
    <?php
}

// Özel alanı kaydet
function save_custom_canonical_url($post_id) {
    if (isset($_POST['custom_canonical_url'])) {
        update_post_meta($post_id, '_custom_canonical_url', esc_url($_POST['custom_canonical_url']));
    }
}
add_action('save_post', 'save_custom_canonical_url');

// Varsayılan ve SEO eklentisi canonical etiketlerini kaldır
function remove_default_canonical() {
    remove_action('wp_head', 'rel_canonical');

    // Yoast SEO canonical etiketini kaldır
    add_filter('wpseo_canonical', '__return_false');

    // Rank Math SEO canonical etiketini kaldır
    add_filter('rank_math/frontend/canonical', '__return_false');

    // All in One SEO Pack canonical etiketini kaldır
    add_filter('aioseop_canonical_url', '__return_false');
}
add_action('wp', 'remove_default_canonical');

// Canonical etiketi ekle
function add_custom_canonical_tag() {
    if (is_singular(['post', 'page'])) {
        global $post;
        $custom_canonical_url = get_post_meta($post->ID, '_custom_canonical_url', true);
        if ($custom_canonical_url) {
            echo '<link rel="canonical" href="' . esc_url($custom_canonical_url) . '">';
        } else {
            echo '<link rel="canonical" href="' . get_permalink($post->ID) . '">';
        }
    }
}
// Önceliği yüksek bir numara vererek diğer eklentilerden önce çalışmasını sağlıyoruz
add_action('wp_head', 'add_custom_canonical_tag', 1);
